/******************************************************************************
* File Name: calibration.c
*  Version 2.1
*
* Description:
*  This file contains code used for zero current calibration measurement 
*  and VSSA measurement for correlated double sampling
*
* Note:
*
********************************************************************************
* Copyright (2012), Cypress Semiconductor Corporation. All Rights Reserved.
********************************************************************************
* This software is owned by Cypress Semiconductor Corporation (Cypress)
* and is protected by and subject to worldwide patent protection (United
* States and foreign), United States copyright laws and international treaty
* provisions. Cypress hereby grants to licensee a personal, non-exclusive,
* non-transferable license to copy, use, modify, create derivative works of,
* and compile the Cypress Source Code and derivative works for the sole
* purpose of creating custom software in support of licensee product to be
* used only in conjunction with a Cypress integrated circuit as specified in
* the applicable agreement. Any reproduction, modification, translation,
* compilation, or representation of this software except as specified above 
* is prohibited without the express written permission of Cypress.
*
* Disclaimer: CYPRESS MAKES NO WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, WITH 
* REGARD TO THIS MATERIAL, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED 
* WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
* Cypress reserves the right to make changes without further notice to the 
* materials described herein. Cypress does not assume any liability arising out 
* of the application or use of any product or circuit described herein. Cypress 
* does not authorize its products for use as critical components in life-support 
* systems where a malfunction or failure may reasonably be expected to result in 
* significant injury to the user. The inclusion of Cypress' product in a life-
* support systems application implies that the manufacturer assumes all risk of 
* such use and in doing so indemnifies Cypress against all charges. 
*
* Use of this Software may be limited by and subject to the applicable Cypress
* software license agreement. 
*******************************************************************************/
#include "calibration.h"


/* Calibration coefficient for RTD */
extern float rtdScaleFactor;

/* Calibration coefficent for diode1 and diode 2*/
extern float diode1ScaleFactor, diode2ScaleFactor;

/* Calibration coefficent for IC */
extern float cjCalibrationConst;

/* Flags indicating whether sensor is calibrated or not */
extern uint8 rtdCalibratedFlag, diode1CalibratedFlag, diode2CalibratedFlag, ICCalibratedFlag;

/* calibration temperatures entered by user */


/*******************************************************************************
*  Function Name: GetVssaRefSample
********************************************************************************
* Summary:
*  This function reads Vssa Ref value. 
*
* Parameters:
* void:
*
* Return:
* int32: Returns the Vssa ref value for CDS 
*
* Theory:
*
* Side Effects:
* None
*******************************************************************************/
int32 GetVssaRefSample(void)
{
    int32 result = 0;
      
   /* Switch the amux to Vssa gnd ref channel 
    * start the ADC conversion */
	ADCMux_FastSelect(VSSA_GND_REF_CHANNEL);
    ADC_StartConvert();
    
	/* Get the ADC value */
    ADC_IsEndConversion(ADC_WAIT_FOR_RESULT);
    result = ADC_GetResult32();
     
	/* Stop the ADC */  
    ADC_StopConvert();

    return result;
}

/*******************************************************************************
*  Function Name: GetRcalOffset
********************************************************************************
* Summary:
*  This function reads voltage across calibration resistor used for current
* calibration for RTD at zero current. This is used to remove offset error
* across calibration resistor at zero current.
*
* Parameters:
* void:
*
* Return:
* int32: Zero current offset volatage across calibration resistor 
*
* Theory:
*
* Side Effects:
* None
*******************************************************************************/
int32 GetRcalOffset(void)
{
    int32 result = 0;
	
	/* Start IDAC  */
    IDAC_Start();
	
	/* Set IDAC current to 0 */
	IDAC_SetValue(0);
    
	/* Route IDAC output to channel 1 to measure zero current */
    CurrentMux_FastSelect(CAL_IDAC_CHANNEL);
	
	/* Switch to calibration channel to measure the voltage across 
	 reference resistor at zero current */
    ADCMux_FastSelect(CAL_CHANNEL);
    
	/* Get the zero current voltage across ref resistor using ADC*/
	ADC_StartConvert();
    ADC_IsEndConversion(ADC_WAIT_FOR_RESULT);
    result = ADC_GetResult32();
	
	/* Stop ADC and IDAC */
    ADC_StopConvert();    
    IDAC_Stop();
    
    return result;
}

/* [] END OF FILE */
